@@ -17,6 +17,9 @@
 # CAM signature/authentication error
 AUTHFAILURE = 'AuthFailure'
 
+# DryRun operation, which means the DryRun parameter is passed in yet the request will still be successful.
+DRYRUNOPERATION = 'DryRunOperation'
+
 # Operation failed.
 FAILEDOPERATION = 'FailedOperation'
 
@@ -77,11 +80,23 @@ LIMITEXCEEDED = 'LimitExceeded'
 # Missing parameter.
 MISSINGPARAMETER = 'MissingParameter'
 
+# Operation denied.
+OPERATIONDENIED = 'OperationDenied'
+
+# The number of requests exceeds the frequency limit.
+REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
+
+# The resource is occupied.
+RESOURCEINUSE = 'ResourceInUse'
+
 # Insufficient resources.
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
 # Resources do not exist.
 RESOURCENOTFOUND = 'ResourceNotFound'
 
+# The resources have been sold out.
+RESOURCESSOLDOUT = 'ResourcesSoldOut'
+
 # Unauthorized operation.
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
